#[non_exhaustive]pub enum DecodeAdmission {
Unknown,
Possible,
Impossible,
}Expand description
Proof carried from decoder-owned grammars to the scan admission path.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unknown
The decoder does not expose a complete admission predicate. Fail open.
Possible
The decoder grammar can produce at least one output candidate.
Impossible
The decoder grammar proves that it cannot produce output.