pub enum MlScoreResult {
Final(f64),
Pending {
heuristic_conf: f64,
code_context: CodeContext,
credential: String,
ml_context: String,
},
}Expand description
Result of calculating a match’s final confidence score.
Variants
Final(f64)
Score is final and the match can be pushed immediately.
Pending
ML scoring is deferred to a batch call at the end of the scan.