pub struct PreprocessedText {
pub text: String,
pub original_end: usize,
pub mappings: Vec<LineMapping>,
}Expand description
Result of preprocessing text for multi-line concatenation.
Fields
text: StringOriginal text plus appended multiline-joined segments.
original_end: usizeByte offset where appended joined segments start.
mappings: Vec<LineMapping>Mapping from offsets in text to original line numbers.
Implementations
Sourceimpl PreprocessedText
impl PreprocessedText
Sourcepub fn line_for_offset(&self, offset: usize) -> Option<usize>
pub fn line_for_offset(&self, offset: usize) -> Option<usize>
Map a byte offset in preprocessed text back to an original line number.
Sourcepub fn passthrough(text: &str) -> Self
pub fn passthrough(text: &str) -> Self
Build a preprocessed representation with a one-line identity mapping.